OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontaktai",
    "Download" : "Atsisiųsti",
    "Copy link" : "Kopijuoti nuorodą",
    "Click to copy the link to your clipboard" : "Kopijuoti nuorodą į iškarpinę",
    "Toggle sharing" : "Perjungti dalinimo būseną",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "Share with users or groups" : "Pasidalinti su...",
    "can edit" : "leidžiama redaguoti",
    "Close" : "Užverti",
    "Enabled" : "Įjungta",
    "Disabled" : "Išjungta",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Nukopijuokite su ⌘-C.",
    "Press Ctrl-C to copy." : "Nukopijuokite su Ctrl-C.",
    "Address book name" : "Adresatų knygos pavadinimas",
    "Only these special characters are allowed: -_.!?#|()" : "Yra leidžiami tik šie specialūs simboliai: -_.!?#|()",
    "Address book could not be created." : "Nepavyko sukurti adresų knygos.",
    "Upload new image" : "Įkelti naują paveikslą",
    "The selected image is too big (max 1MB)" : "Didžiausias nuotraukos dydis yra 1 MB",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ši kortelė nebuvo teisingai išsaugota. Patikrinkite duomenų teisingumą ir išsaugokite.",
    "No contacts in here" : "Nėra adresatų",
    "Name" : "Vardas",
    "Organization" : "Darbo vieta",
    "Title" : "Pareigos",
    "Add field …" : "Pridėti informaciją...",
    "Save changes" : "Įrašyti pakeitimus",
    "Address book" : "Adresatų knyga",
    "Loading contacts …" : "Įkeliami kontaktai…",
    "Import into" : "Importuoti į",
    "Importing..." : "Importuojama...",
    "Select your addressbook" : "Pasirinkti adresų knygą",
    "Import is disabled because no writable address book had been found." : "Importavimas yra išjungtas, nes nerasta jokios rašymui skirtos adresų knygos.",
    "No search result for {query}" : "Nieko nerasta pagal \"{query}\"",
    "All contacts" : "Visi adresatai",
    "Post office box" : "Pašto dėžutės numeris",
    "Postal code" : "Pašto kodas",
    "City" : "Miestas",
    "State or province" : "Rajonas",
    "Country" : "Valstybė",
    "Address" : "Adresas",
    "(new group)" : "(nauja grupė)",
    "Last name" : "Pavardė",
    "First name" : "Vardas",
    "Additional names" : "Kiti vardai",
    "Prefix" : "Kreipiniai",
    "Suffix" : "Patikslinimai",
    "Importing into" : "Importuojama į",
    "New contact" : "Naujas adresatas",
    "Not grouped" : "Negrupuoti",
    "Sort by" : "Rikiuoti pagal",
    "There is no address book available to create a contact." : "Kontakto kūrimui nėra prieinama jokia adresų knyga.",
    "{addressbook} shared by {owner}" : "{owner} pradėjo bendrinti {addressbook}",
    "Contact not found." : "Kontaktinis asmuo nerastas.",
    "You don't have permission to write to this addressbook." : "Jūs neturite leidimo rašyti į šią adresų knygelę.",
    "Contact could not be created." : "Nepavyko sukurti adresato.",
    "No contacts in file. Only vCard files are allowed." : "Byloje nėra adresatų duomenų. Tik vCard tipo bylos palaikomos.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Palaikomos vCard 4.0 versija (RFC6350) ir vCard 3.0 versija (RFC2426).",
    "Contact could not be moved." : "Nepavyko perkelti kontakto.",
    "Contact could not be saved." : "Nepavyko įrašyti adresato.",
    "Waiting for the server to be ready…" : "Laukiama kol serveris bus pasiruošęs...",
    "Importing…" : "Importuojama...",
    "Display name" : "Rodomas vardas",
    "Nickname" : "Slapyvardis",
    "Detailed name" : "Pilnas vardas",
    "Notes" : "Apie",
    "Website" : "Svetainė",
    "Federated Cloud ID" : "Centralizuoto Serverio ID",
    "Home" : "Namų",
    "Work" : "Darbo",
    "Other" : "Neapibrėžtas",
    "Groups" : "Grupės",
    "Birthday" : "Gimimo data",
    "Anniversary" : "Santuokos data",
    "Date of death" : "Mirties data",
    "Email" : "Elektroninio pašto adresas",
    "Instant messaging" : "Momentinių pranešimų paskyra",
    "Phone" : "Telefono numeris",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Fax" : "Telefakso",
    "Fax home" : "Namų telefakso",
    "Fax work" : "Darbinio telefakso",
    "Pager" : "Pranešimų gaviklio",
    "Voice" : "Balso pašto",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Social network" : "Socialinio tinklo paskyra",
    "Relationship" : "Ryšiai",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaičiai",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbiai",
    "Manager" : "Vadovas",
    "Assistant" : "Asistentas",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "Details" : "Išsamesnė informacija",
    "Settings" : "Nustatymai"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
